@@ -10,8 +10,12 @@ writeDescriptionSDML <- function(title="RDataset", source="R",
     cat("<date>", date, "</date>\n", file=file, append=T, sep=" ")
     catSDML("<version>", version, "</version>\n", file=file)
     catSDML("<comment>", comment, "</comment>\n", file=file)
+    sdmlib <- .path.package("StatDataML")
+    sdmlib <- substr(sdmlib, 1, nchar(sdmlib)-10)
     catSDML("<creator>R-", R.version$major, ".",  R.version$minor,
-            ":StatDataML_0.1-7</creator>\n", file=file)
+            ":StatDataML_",
+            package.description("StatDataML", lib=sdmlib)$Version,
+            "</creator>\n", file=file)
     catSDML("<class>", class, "</class>\n", file=file)
     catSDML("</description>\n", file=file)
 }
